﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using HeuristicLab.DataImporter.Command.View;
using HeuristicLab.DataImporter.Data;
using HeuristicLab.DataImporter.Data.CommandBase;
using HeuristicLab.DataImporter.Data.Model;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using HEAL.Attic;

namespace HeuristicLab.DataImporter.Command {
  [StorableType("91A0FDBD-841F-417E-BF6A-30760E351114")]
  [ViewableCommandInfoAttribute("Minimum", 1, ColumnGroupState.DoubleColumnSelected | ColumnGroupState.AnySelectedColumnNotSorted,
   "Aggregation", Position = 3, OptionsView = typeof(AggregationCommandView))]
  public class AggregateWithMinCommand : AggregateCommandBase {
    [StorableConstructor]
    protected AggregateWithMinCommand(bool deserializing) : base(deserializing) { }

    public AggregateWithMinCommand(DataSet dataSet, string columnGroupName, int[] affectedColumns)
      : base(dataSet, columnGroupName, affectedColumns) {
    }

    public override string Description {
      get { return "Aggregate with min function"; }
    }

    protected override IComparable AggregationFunction(ColumnBase col, int startIndex, int endIndex) {
      IComparable minValue = null;
      IComparable val;
      for (int i = startIndex; i < endIndex; i++) {
        val = col.GetValue(i);
        if (val != null) {
          if (minValue == null || val.CompareTo(minValue) < 0)
            minValue = val;
        }
      }
      return minValue;
    }
  }
}
